<?php

/*
Plugin Name: Bookmarks Displayer Widget
Plugin URI: http://wordpress.org/
Description: Wordpress plugin widget that allows readers to display bookmarks in the sort order of their choosing.
Version: 0.6
Author: Nathan Oliphant
Author URI: http://oliphantparts.org/

To use, upload the unzipped folder to your wp-content/plugins directory, then go to Presentation-> Widgets and add it to your sidebar.
If you click on the configure icon, you can add whatever title you want (the default title is 'BLOGROLL') and change the Order By,
Order and Limit options for your blogroll.

Updated: 16JUL2008 to include changes made by Matthias Gall at http://www.digitalbreed.com/ to correct several bugs.
*/

// We're putting the plugin's functions in one big function we then
// call at 'plugins_loaded' (add_action() at bottom) to ensure the
// required Sidebar Widget functions are available.
function bookmarks_displayer_widget_init() {

    // Check to see required Widget API functions are defined...
    if ( !function_exists('register_sidebar_widget') || !function_exists('register_widget_control') )
        return; // ...and if not, exit gracefully from the script.

    // This function prints the sidebar widget--the cool stuff!
    function bookmarks_displayer_widget($args) {

        // $args is an array of strings which help your widget
        // conform to the active theme: before_widget, before_title,
        // after_widget, and after_title are the array keys.
        extract($args);

        // Collect our widget's options, or define their defaults.
        $options          = get_option('bookmarks_displayer_widget');
        $title            = empty( $options['title'] )            ? 'Blogroll' : $options['title'];
        $text             = empty( $options['text'] )             ? 'name'     : $options['text'];
        $order            = empty( $options['order'] )            ? 'ASC'      : $options['order'];
        $limit            = empty( $options['limit'] )            ? '-1'       : $options['limit'];
        // $category added by Matthias Gall  (http://www.digitalbreed.com/)
        $category         = empty( $options['category'] )         ? ''         : $options['category'];

         // It's important to use the $before_widget, $before_title,
         // $after_title and $after_widget variables in your output.
        echo $before_widget;
        echo $before_title . $title . $after_title;
        // $category added by Matthias Gall  (http://www.digitalbreed.com/)
        wp_bookmarks_order( $title, $text, $order, $limit, $category );
        echo $after_widget;
    }

    // This is the function that outputs the form to let users edit
    // the widget's title and so on. It's an optional feature, but
    // we'll use it because we can!
    function bookmarks_displayer_widget_control() {

        // Collect our widget's options.
        // Options update and check for is_array added by Matthias Gall  (http://www.digitalbreed.com/)
        // $options = get_option('bookmarks_displayer_widget');
        $options = $newoptions = get_option('bookmarks_displayer_widget');
        if ( !is_array($options) )
          $options = $newoptions = array();

        // This is for handing the control form submission.
        // Addition of category and check for isset added by Matthias Gall  (http://www.digitalbreed.com/)
        if ( isset( $_POST[ "bookmarks_displayer_widget-submit" ] ) ) {
            // Clean up control form submission options
            $newoptions['title']            = strip_tags(stripslashes($_POST["bookmarks_widget-title"]));
            $newoptions['text']             = strip_tags(stripslashes($_POST["bookmarks_widget-text"]));
            $newoptions['order']            = strip_tags(stripslashes($_POST["bookmarks_widget-order"]));
            $newoptions['limit']            = strip_tags(stripslashes($_POST["bookmarks_widget-limit"]));
            $newoptions['category']			= strip_tags(stripslashes($_POST["bookmarks_widget-category"]));
        }

        // If original widget options do not match control form
        // submission options, update them.
        if ( $options != $newoptions ) {
            $options = $newoptions;
            update_option('bookmarks_displayer_widget', $options);
        }

        // Format options as valid HTML.
        $title            = htmlspecialchars( $options['title'],            ENT_QUOTES);
        $text             = htmlspecialchars( $options['text'],             ENT_QUOTES);
        $order            = htmlspecialchars( $options['order'],            ENT_QUOTES);
        $limit            = htmlspecialchars( $options['limit'],            ENT_QUOTES);
        // Addition of category added by Matthias Gall  (http://www.digitalbreed.com/)
        $category         = htmlspecialchars( $options['category'],			ENT_QUOTES);


// The HTML below is the control form for editing options.
?>
        <div>
        <label for="bookmarks_widget-title" style="line-height:35px;display:block;">Title: <input type="text" id="bookmarks_widget-title" name="bookmarks_widget-title" value="<?php echo $title; ?>" /></label>
        <label for="bookmarks_widget-category" style="line-height:35px;display:block;">Category-ID:
        <input type="text" id="bookmarks_widget-category" name="bookmarks_widget-category" value="<?php if ($category == '' ) { $category = "0"; } echo $category; ?>" /></label>
        <label for="bookmarks_widget-limit" style="line-height:35px;display:block;">Limit:
        <input type="text" id="bookmarks_widget-limit" name="bookmarks_widget-limit" value="<?php if ($limit == '' ) { $limit = -1; } echo $limit; ?>" onBlur="checkLimit(this)" /></label>
        <label for="bookmarks_widget-text" style="line-height:35px;display:block;">Order By:
        <select id="bookmarks_widget-text" name="bookmarks_widget-text">
          <option value="name"<?php if ( $text=='name' ) { echo 'selected="selected"'; }?>>Name</option>
          <option value="category"<?php if ( $text=='category' ) { echo 'selected="selected"'; }?>>Category</option>
          <option value="Description"<?php if ( $text=='Description' ) { echo 'selected="selected"'; }?>>Description</option>
          <option value="id"<?php if ( $text=='id' ) { echo 'selected="selected"'; }?>>ID</option>
          <option value="length"<?php if ( $text=='length' ) { echo 'selected="selected"'; }?>>Length</option>
          <option value="notes"<?php if ( $text=='notes' ) { echo 'selected="selected"'; }?>>Notes</option>
          <option value="owner"<?php if ( $text=='owner' ) { echo 'selected="selected"'; }?>>Owner</option>
          <option value="rand"<?php if ( $text=='rand' ) { echo 'selected="selected"'; }?>>Random</option>
          <option value="rating"<?php if ( $text=='rating' ) { echo 'selected="selected"'; }?>>Rating</option>
          <option value="rel"<?php if ( $text=='rel' ) { echo 'selected="selected"'; }?>>Rel</option>
          <option value="rss"<?php if ( $text=='rss' ) { echo 'selected="selected"'; }?>>RSS</option>
          <option value="target"<?php if ( $text=='target' ) { echo 'selected="selected"'; }?>>Target</option>
          <option value="updated"<?php if ( $text=='updated' ) { echo 'selected="selected"'; }?>>Updated</option>
          <option value="url"<?php if ( $text=='url' ) { echo 'selected="selected"'; }?>>URL</option>
        </select></label>
        <label for="bookmarks_widget-order" style="line-height:35px;display:block;">Order:
        <select id="bookmarks_widget-order" name="bookmarks_widget-order">
          <option value="ASC"<?php if ( $order=='ASC' ) { echo 'selected="selected"'; }?>>Ascending</option>
          <option value="DESC"<?php if ( $order=='DESC' ) { echo 'selected="selected"'; }?>>Descending</option>
        </select></label>
        <!--label for="bookmarks_widget-show_images" style="line-height:35px;display:block;">Show Images:
        <select id="bookmarks_widget-show_images" name="bookmarks_widget-show_images">
          <option value="1"< ?php if ( $show_images=='1' ) { echo 'selected="selected"'; }?>>True</option>
          <option value="0"< ?php if ( $show_images=='0' ) { echo 'selected="selected"'; }?>>False</option>
        </select></label>
        <label for="bookmarks_widget-show_description " style="line-height:35px;display:block;">Show Description:
        <select id="bookmarks_widget-show_description " name="bookmarks_widget-show_description ">
          <option value="1"< ?php if ( $show_description =='1' ) { echo 'selected="selected"'; }? >>True</option>
          <option value="0"< ?php if ( $show_description =='0' ) { echo 'selected="selected"'; }? >>False (default)</option>
        </select></label>
        <label for="bookmarks_widget-show_rating" style="line-height:35px;display:block;">Show Rating:
        <select id="bookmarks_widget-show_rating" name="bookmarks_widget-show_rating">
          <option value="1"< ?php if ( $show_rating =='1' ) { echo 'selected="selected"'; }? >>True</option>
          <option value="0"< ?php if ( $show_rating =='0' ) { echo 'selected="selected"'; }? >>False (default)</option>
        </select></label>
        <label for="bookmarks_widget-show_updated" style="line-height:35px;display:block;">Show Updated:
        <select id="bookmarks_widget-show_updated" name="bookmarks_widget-show_updated">
          <option value="1"< ?php if ( $show_updated =='1' ) { echo 'selected="selected"'; }? >>True</option>
          <option value="0"< ?php if ( $show_updated =='0' ) { echo 'selected="selected"'; }? >>False (default)</option>
        </select></label-->
        <input type="hidden" name="bookmarks_displayer_widget-submit" id="bookmarks_displayer_widget-submit" value="1" />
        <script language="JavaScript" type="text/javascript">
        function checkLimit( lim )
        {
          val = lim.value;
          if ( isNaN( val ) )
          {
            alert("Limit: " + val + " is not a number.\nThis is the number of blogroll entries to display.\nEnter -1 to display all." );
            lim.value = -1;
            lim.focus();
          }
        }
        </script>
        </div>
    <?php
    // end of bookmarks_displayer_widget_control()
    }

    // This registers the widget. About time.
    register_sidebar_widget('Bookmarks Order Widget', 'bookmarks_displayer_widget');

    // This registers the (optional!) widget control form.
    register_widget_control('Bookmarks Order Widget', 'bookmarks_displayer_widget_control');
}

// Delays plugin execution until Dynamic Sidebar has loaded first.
add_action('plugins_loaded', 'bookmarks_displayer_widget_init');

function wp_bookmarks_order( $title, $text, $order, $limit, $category )
{
  $array = array( 'categorize' => 0,
  					'title_li' => __(''),
					'title_before' => '',
					'title_after' => '',
					'order' => $order,
					'orderby' => $text,
					'limit' => $limit,
					'category' => $category,
					'before' => '<li class="icon music">'
					);
   
  /*
    Matt's update included an 'echo' => false, as shown below, but this caused the blogroll not to appear on the site with Wordpress version 2.5.1, so I've commented it out.  
    You might want to try the following version of the array instead of the above version if you are having any problems with your version of Wordpress.
    $array = array( 'categorize' => 0,
  					'title_li' => __(''),
					'title_before' => '',
					'title_after' => '',
					'order' => $order,
					'orderby' => $text,
					'limit' => $limit,
					'category' => $category,
					'before' => '<li class="icon music">',
					'echo' => false
					);
     */

  echo '<ul id="bookmarkswidget">'."\n";
  if( function_exists( 'wp_ozh_click_modifyhrefs' ) )
  {
  	$out = wp_list_bookmarks( $array );
    echo wp_ozh_click_modifyhrefs( $out );
  }
  else
  {
  	wp_list_bookmarks( $array );
  }

  echo '</ul>'."\n";
  //echo $ts;
}
?>
